@@ -9,9 +9,10 @@ use strict;
 use warnings;
 
 use Algorithm::Combinatorics qw( permutations );
+use List::Util qw( max min );
 use List::MoreUtils qw( zip );
 
-our $VERSION = '0.0801';
+our $VERSION = '0.09';
 
 
 
@@ -99,6 +100,41 @@ sub counter_strategy
     return $counter_strategy;
 }
 
+
+sub saddlepoint
+{
+    my ($self) = @_;
+
+    my $saddlepoint;
+    my $size = @{ $self->{payoff}[0] } - 1;
+
+    POINT:
+    for my $row ( 0 .. $size )
+    {
+        my $min = min @{ $self->{payoff}[$row] };
+        for my $col ( 0 .. $size )
+        {
+            my $v = $self->{payoff}[$row][$col];
+            if ( $v == $min )
+            {
+                my @col;
+                for my $z ( 0 .. $size )
+                {
+                    push @col, $self->{payoff}[$z][$col];
+                }
+                my $max = max @col;
+                if ( $v == $max )
+                {
+                    $saddlepoint = $v;
+                    last POINT;
+                }
+            }
+        }
+    }
+
+    return $saddlepoint;
+}
+
 1;
 
 __END__
@@ -113,7 +149,7 @@ Game::Theory::TwoPersonMatrix - Analyze a 2 person matrix game
 
 =head1 VERSION
 
-version 0.0801
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -188,6 +224,13 @@ examples.
 
 Return the counter-strategies for a given player.
 
+=head2 saddlepoint()
+
+ $v = $g->saddlepoint;
+
+If the game is strictly determined, the saddlepoint is returned.  Otherwise
+C<undef> is returned.
+
 =head1 SEE ALSO
 
 "A Gentle Introduction to Game Theory"
